### Links

* Docs: [palewi.re/docs/django-yamlfield/](https://palewi.re/docs/django-yamlfield/)
* Issues: [github.com/datadesk/django-yamlfield/issues](https://github.com/datadesk/django-yamlfield/issues)
* Packaging: [pypi.python.org/pypi/django-yamlfield](https://pypi.python.org/pypi/django-yamlfield)
* Testing: [github.com/datadesk/django-yamlfield/actions](https://github.com/datadesk/django-yamlfield/actions)
